@@ -176,11 +176,7 @@ class ControlHostBootstrap(KayobeAnsibleMixin, KollaAnsibleMixin, VaultMixin,
             # environment, we should also generate the admin-openrc.sh and
             # public-openrc.sh scripts that provide admin credentials.
 
-            # FIXME: Fudge to work around incorrect configuration path.
-            extra_vars = {"node_config_directory":
-                          parsed_args.kolla_config_path}
-            self.run_kolla_ansible_overcloud(parsed_args, "post-deploy",
-                                             extra_vars=extra_vars)
+            self.run_kolla_ansible_overcloud(parsed_args, "post-deploy")
             # Create an environment file for accessing the public API as the
             # admin user.
             playbooks = _build_playbook_list("public-openrc")
@@ -550,7 +546,7 @@ class SeedHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         playbooks += _build_playbook_list(
             "users", "yum", "dev-tools", "disable-selinux", "network",
             "sysctl", "ip-routing", "snat", "disable-glean", "ntp", "mdadm",
-            "lvm")
+            "lvm", "docker-devicemapper")
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed")
 
         self.generate_kolla_ansible_config(parsed_args, service_config=False)
@@ -950,7 +946,7 @@ class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         playbooks += _build_playbook_list(
             "users", "yum", "dev-tools", "disable-selinux", "network",
             "sysctl", "disable-glean", "disable-cloud-init", "ntp", "mdadm",
-            "lvm")
+            "lvm", "docker-devicemapper")
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
 
         self.generate_kolla_ansible_config(parsed_args, service_config=False)
@@ -1207,11 +1203,6 @@ class OvercloudServiceDeploy(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         if not parsed_args.skip_prechecks:
             self.run_kolla_ansible_overcloud(parsed_args, "prechecks")
 
-        # Workaround: Stop the chrony container.
-        # TODO(mgoddard): Remove in the Train cycle.
-        playbooks = _build_playbook_list("stop-chrony")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
-
         # Perform the kolla-ansible deployment.
         self.run_kolla_ansible_overcloud(parsed_args, "deploy")
 
@@ -1222,16 +1213,56 @@ class OvercloudServiceDeploy(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
                                   extra_vars=extra_vars, limit="overcloud")
 
         # Post-deployment configuration.
-        # FIXME: Fudge to work around incorrect configuration path.
-        extra_vars = {"node_config_directory": parsed_args.kolla_config_path}
-        self.run_kolla_ansible_overcloud(parsed_args, "post-deploy",
-                                         extra_vars=extra_vars)
+        self.run_kolla_ansible_overcloud(parsed_args, "post-deploy")
         # Create an environment file for accessing the public API as the admin
         # user.
         playbooks = _build_playbook_list("public-openrc")
         self.run_kayobe_playbooks(parsed_args, playbooks, ignore_limit=True)
 
 
+class OvercloudServiceDeployContainers(KollaAnsibleMixin, KayobeAnsibleMixin,
+                                       VaultMixin, Command):
+    """Deploy the overcloud services without updating configuration.
+
+    * Configure kolla-ansible.
+    * Configure overcloud services in kolla-ansible.
+    * Perform kolla-ansible prechecks to verify the system state for
+      deployment.
+    * Perform a kolla-ansible deployment of the overcloud service containers.
+    * Configure and deploy kayobe extra services.
+
+    This can be used in conjunction with the --tags and --kolla-tags arguments
+    to deploy specific services.
+    """
+
+    def get_parser(self, prog_name):
+        parser = super(OvercloudServiceDeployContainers, self).get_parser(
+            prog_name)
+        group = parser.add_argument_group("Service Deployment")
+        group.add_argument("--skip-prechecks", action='store_true',
+                           help="skip the kolla-ansible prechecks command")
+        return parser
+
+    def take_action(self, parsed_args):
+        self.app.LOG.debug("Deploying overcloud services (containers only)")
+
+        # First prepare configuration.
+        self.generate_kolla_ansible_config(parsed_args)
+
+        # Run kolla-ansible prechecks before deployment.
+        if not parsed_args.skip_prechecks:
+            self.run_kolla_ansible_overcloud(parsed_args, "prechecks")
+
+        # Perform the kolla-ansible deployment.
+        self.run_kolla_ansible_overcloud(parsed_args, "deploy-containers")
+
+        # Deploy kayobe extra services.
+        playbooks = _build_playbook_list("overcloud-extras")
+        extra_vars = {"kayobe_action": "deploy"}
+        self.run_kayobe_playbooks(parsed_args, playbooks,
+                                  extra_vars=extra_vars, limit="overcloud")
+
+
 class OvercloudServiceReconfigure(KollaAnsibleMixin, KayobeAnsibleMixin,
                                   VaultMixin, Command):
     """Reconfigure the overcloud services.
@@ -1265,11 +1296,6 @@ class OvercloudServiceReconfigure(KollaAnsibleMixin, KayobeAnsibleMixin,
         if not parsed_args.skip_prechecks:
             self.run_kolla_ansible_overcloud(parsed_args, "prechecks")
 
-        # Workaround: Stop the chrony container.
-        # TODO(mgoddard): Remove in the Train cycle.
-        playbooks = _build_playbook_list("stop-chrony")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
-
         # Perform the kolla-ansible reconfiguration.
         self.run_kolla_ansible_overcloud(parsed_args, "reconfigure")
 
@@ -1280,10 +1306,7 @@ class OvercloudServiceReconfigure(KollaAnsibleMixin, KayobeAnsibleMixin,
                                   extra_vars=extra_vars, limit="overcloud")
 
         # Post-deployment configuration.
-        # FIXME: Fudge to work around incorrect configuration path.
-        extra_vars = {"node_config_directory": parsed_args.kolla_config_path}
-        self.run_kolla_ansible_overcloud(parsed_args, "post-deploy",
-                                         extra_vars=extra_vars)
+        self.run_kolla_ansible_overcloud(parsed_args, "post-deploy")
         # Create an environment file for accessing the public API as the admin
         # user.
         playbooks = _build_playbook_list("public-openrc")
@@ -1322,11 +1345,6 @@ class OvercloudServiceUpgrade(KollaAnsibleMixin, KayobeAnsibleMixin,
         if not parsed_args.skip_prechecks:
             self.run_kolla_ansible_overcloud(parsed_args, "prechecks")
 
-        # Workaround: Stop the chrony container.
-        # TODO(mgoddard): Remove in the Train cycle.
-        playbooks = _build_playbook_list("stop-chrony")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
-
         # Perform the kolla-ansible upgrade.
         self.run_kolla_ansible_overcloud(parsed_args, "upgrade")
 
