@@ -101,7 +101,6 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 "post-deploy",
-                extra_vars={"node_config_directory": "/etc/kolla"},
             )
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
@@ -327,6 +326,7 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "network.yml"),
                     utils.get_data_files_path("ansible", "sysctl.yml"),
                     utils.get_data_files_path("ansible", "ntp.yml"),
+                    utils.get_data_files_path("ansible", "mdadm.yml"),
                     utils.get_data_files_path("ansible", "lvm.yml"),
                     utils.get_data_files_path(
                         "ansible", "seed-hypervisor-libvirt-host.yml"),
@@ -360,6 +360,84 @@ class TestCase(unittest.TestCase):
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_seed_hypervisor_host_package_update_all(self, mock_run):
+        command = commands.SeedHypervisorHostPackageUpdate(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--packages", "*"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "host-package-update.yml"),
+                ],
+                limit="seed-hypervisor",
+                extra_vars={
+                    "host_package_update_packages": "*",
+                    "host_package_update_security": False,
+                },
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_seed_hypervisor_host_package_update_list(self, mock_run):
+        command = commands.SeedHypervisorHostPackageUpdate(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--packages", "p1,p2"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "host-package-update.yml"),
+                ],
+                limit="seed-hypervisor",
+                extra_vars={
+                    "host_package_update_packages": "p1,p2",
+                    "host_package_update_security": False,
+                },
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_seed_hypervisor_host_package_update_security(self, mock_run):
+        command = commands.SeedHypervisorHostPackageUpdate(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--packages", "*", "--security"])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "host-package-update.yml"),
+                ],
+                limit="seed-hypervisor",
+                extra_vars={
+                    "host_package_update_packages": "*",
+                    "host_package_update_security": True,
+                },
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_seed_hypervisor_host_upgrade(self, mock_run):
@@ -430,7 +508,10 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "snat.yml"),
                     utils.get_data_files_path("ansible", "disable-glean.yml"),
                     utils.get_data_files_path("ansible", "ntp.yml"),
+                    utils.get_data_files_path("ansible", "mdadm.yml"),
                     utils.get_data_files_path("ansible", "lvm.yml"),
+                    utils.get_data_files_path("ansible",
+                                              "docker-devicemapper.yml"),
                 ],
                 limit="seed",
             ),
@@ -898,7 +979,7 @@ class TestCase(unittest.TestCase):
         expected_calls = [
             mock.call(
                 mock.ANY,
-                "deploy-bifrost",
+                "upgrade-bifrost",
             ),
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
@@ -1054,7 +1135,10 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path(
                         "ansible", "disable-cloud-init.yml"),
                     utils.get_data_files_path("ansible", "ntp.yml"),
+                    utils.get_data_files_path("ansible", "mdadm.yml"),
                     utils.get_data_files_path("ansible", "lvm.yml"),
+                    utils.get_data_files_path("ansible",
+                                              "docker-devicemapper.yml"),
                 ],
                 limit="overcloud",
             ),
@@ -1074,6 +1158,8 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path("ansible", "docker.yml"),
                     utils.get_data_files_path(
                         "ansible", "ceph-block-devices.yml"),
+                    utils.get_data_files_path(
+                        "ansible", "swift-block-devices.yml"),
                 ],
                 limit="overcloud",
                 extra_vars={"pip_applicable_users": [None]},
@@ -1322,6 +1408,76 @@ class TestCase(unittest.TestCase):
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
+    @mock.patch.object(commands.KollaAnsibleMixin,
+                       "run_kolla_ansible_overcloud")
+    def test_overcloud_database_backup(self, mock_run):
+        command = commands.OvercloudDatabaseBackup(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args([])
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                "mariadb_backup",
+                extra_args=[]
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+    @mock.patch.object(commands.KollaAnsibleMixin,
+                       "run_kolla_ansible_overcloud")
+    def test_overcloud_database_backup_incremental(self, mock_run):
+        command = commands.OvercloudDatabaseBackup(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--incremental"])
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                "mariadb_backup",
+                extra_args=["--incremental"]
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+    @mock.patch.object(commands.KollaAnsibleMixin,
+                       "run_kolla_ansible_overcloud")
+    def test_overcloud_database_recover(self, mock_run):
+        command = commands.OvercloudDatabaseRecover(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args([])
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                "mariadb_recovery",
+                extra_vars={}
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+    @mock.patch.object(commands.KollaAnsibleMixin,
+                       "run_kolla_ansible_overcloud")
+    def test_overcloud_database_recover_force_host(self, mock_run):
+        command = commands.OvercloudDatabaseRecover(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args(["--force-recovery-host", "foo"])
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                "mariadb_recovery",
+                extra_vars={
+                    "mariadb_recover_inventory_name": "foo"
+                }
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_overcloud_service_configuration_save(self, mock_run):
@@ -1369,20 +1525,6 @@ class TestCase(unittest.TestCase):
                 ],
                 ignore_limit=True,
             ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible",
-                                              "swift-setup.yml"),
-                ],
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible", "stop-chrony.yml"),
-                ],
-                limit="overcloud",
-            ),
             mock.call(
                 mock.ANY,
                 [
@@ -1416,9 +1558,60 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 "post-deploy",
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
+
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    @mock.patch.object(commands.KollaAnsibleMixin,
+                       "run_kolla_ansible_overcloud")
+    def test_overcloud_service_deploy_containers(self, mock_kolla_run,
+                                                 mock_run):
+        command = commands.OvercloudServiceDeployContainers(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args([])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
+                ignore_limit=True,
+                tags="config",
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible",
+                                              "kolla-openstack.yml"),
+                ],
+                ignore_limit=True,
+            ),
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible",
+                                              "overcloud-extras.yml"),
+                ],
+                limit="overcloud",
                 extra_vars={
-                    "node_config_directory": "/etc/kolla",
-                }
+                    "kayobe_action": "deploy",
+                },
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                "prechecks",
+            ),
+            mock.call(
+                mock.ANY,
+                "deploy-containers",
             ),
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
@@ -1450,20 +1643,6 @@ class TestCase(unittest.TestCase):
                 ],
                 ignore_limit=True,
             ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible",
-                                              "swift-setup.yml"),
-                ],
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible", "stop-chrony.yml"),
-                ],
-                limit="overcloud",
-            ),
             mock.call(
                 mock.ANY,
                 [
@@ -1497,9 +1676,6 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 "post-deploy",
-                extra_vars={
-                    "node_config_directory": "/etc/kolla",
-                }
             ),
         ]
         self.assertEqual(expected_calls, mock_kolla_run.call_args_list)
@@ -1531,13 +1707,6 @@ class TestCase(unittest.TestCase):
                 ],
                 ignore_limit=True,
             ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible", "stop-chrony.yml"),
-                ],
-                limit="overcloud"
-            ),
             mock.call(
                 mock.ANY,
                 [
@@ -1720,6 +1889,26 @@ class TestCase(unittest.TestCase):
         ]
         self.assertEqual(expected_calls, mock_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_overcloud_swift_rings_generate(self, mock_run):
+        command = commands.OvercloudSwiftRingsGenerate(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args([])
+
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path("ansible", "swift-rings.yml"),
+                ],
+            ),
+        ]
+        self.assertEqual(expected_calls, mock_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_baremetal_compute_inspect(self, mock_run):
